# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 20:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0005_auto_20180707_1612'),
    ]

    operations = [
        migrations.AlterField(
            model_name='splinechart',
            name='x_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='X data format'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='y_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='Y data format'),
        ),
    ]
