# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 19:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='splinechart',
            options={'verbose_name': 'SPLine Chart', 'verbose_name_plural': 'SPLine Charts'},
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='data_url',
            field=models.CharField(help_text='Django url name for getting the data from.', max_length=255, verbose_name='Data URL'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='title',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Title'),
        ),
    ]
