# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 19:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0003_auto_20180707_1501'),
    ]

    operations = [
        migrations.AddField(
            model_name='splinechart',
            name='desc',
            field=models.TextField(blank=True, help_text='Optional chart description', null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='data_url_name',
            field=models.CharField(help_text='Django url name for getting the data from.', max_length=255, verbose_name='Data URL Name'),
        ),
    ]
