# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-08 21:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0006_auto_20180707_1631'),
    ]

    operations = [
        migrations.CreateModel(
            name='PieChart',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Title')),
                ('code', models.CharField(max_length=100, unique=True, verbose_name='Code')),
                ('type', models.IntegerField(choices=[(1, 'pie'), (2, 'spline')], verbose_name='Type')),
                ('data_url_name', models.CharField(help_text='Django url name for getting the data from.', max_length=255, verbose_name='Data URL Name')),
                ('desc', models.TextField(blank=True, help_text='Optional chart description', null=True, verbose_name='Description')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'SPLine Chart',
                'verbose_name_plural': 'SPLine Charts',
            },
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='x_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='X axis data format'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='y_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='Y axis data format'),
        ),
    ]
